@@ -7,7 +7,7 @@ except Exception as e:
 from smtpapi import SMTPAPIHeader
 
 
-class Mail(SMTPAPIHeader):
+class Mail():
 
     """SendGrid Message."""
 
@@ -29,7 +29,6 @@ class Mail(SMTPAPIHeader):
             headers: Set headers
             files: Attachments
         """
-        super(Mail, self).__init__()
         self.to = []
         self.to_name = []
         self.cc = []
@@ -48,9 +47,9 @@ class Mail(SMTPAPIHeader):
         self.headers = opts.get('headers', '')
         self.date = opts.get('date', rfc822.formatdate())
         self.content = opts.get('content', {})
+        self.smtpapi = opts.get('smtpapi', SMTPAPIHeader())
 
     def parse_and_add(self, to):
-        super(Mail, self).add_to(to)
         name, email = rfc822.parseaddr(to.replace(',', ''))
         if email:
             self.to.append(email)
@@ -72,7 +71,8 @@ class Mail(SMTPAPIHeader):
         elif sys.version_info < (3, 0) and isinstance(to_name, unicode):
             self.to_name.append(to_name.encode('utf-8'))
         elif hasattr(to_name, '__iter__'):
-            self.to_name = self.to_name + to_name
+            for tn in to_name:
+                self.add_to_name(tn)
 
     def add_cc(self, cc):
         if isinstance(cc, str):
@@ -119,6 +119,8 @@ class Mail(SMTPAPIHeader):
         self.reply_to = replyto
 
     def add_attachment(self, name, file_):
+        if sys.version_info < (3, 0) and isinstance(name, unicode):
+            name = name.encode('utf-8')
         if isinstance(file_, str):  # filepath
             with open(file_, 'rb') as f:
                 self.files[name] = f.read()
@@ -128,11 +130,9 @@ class Mail(SMTPAPIHeader):
     def add_attachment_stream(self, name, string):
         if sys.version_info < (3, 0) and isinstance(name, unicode):
             name = name.encode('utf-8')
-        if isinstance(string, str):
-            self.files[name] = string
-        elif isinstance(string, io.BytesIO):
+        if isinstance(string, io.BytesIO):
             self.files[name] = string.read()
-        elif sys.version_info < (3, 0) and isinstance(string, unicode):
+        else:
             self.files[name] = string
 
     def add_content_id(self, cid, value):
@@ -143,3 +143,35 @@ class Mail(SMTPAPIHeader):
 
     def set_date(self, date):
         self.date = date
+
+    # SMTPAPI Wrapper methods
+
+    def add_substitution(self, key, value):
+        self.smtpapi.add_substitution(key, value)
+
+    def set_substitutions(self, subs):
+        self.smtpapi.set_substitutions(subs)
+
+    def add_unique_arg(self, key, value):
+        self.smtpapi.add_unique_arg(key, value)
+
+    def set_unique_args(self, args):
+        self.smtpapi.set_unique_args(args)
+
+    def add_category(self, cat):
+        self.smtpapi.add_category(cat)
+
+    def set_categories(self, cats):
+        self.smtpapi.set_categories(cats)
+
+    def add_section(self, key, value):
+        self.smtpapi.add_section(key, value)
+
+    def set_sections(self, sections):
+        self.smtpapi.set_sections(sections)
+
+    def add_filter(self, filterKey, setting, value):
+        self.smtpapi.add_filter(filterKey, setting, value)
+
+    def json_string(self):
+        return self.smtpapi.json_string()
